@@ -1,16 +1,15 @@
-# coding: utf-8
-
 # flake8: noqa
 
 # import all models into this package
 # if you have many models here with many references from one model to another this may
 # raise a RecursionError
 # to avoid this, import only the models that you directly need like:
-# from resview_client.model.pet import Pet
+# from from resview_client.model.pet import Pet
 # or import this package, but before doing it, use:
 # import sys
 # sys.setrecursionlimit(n)
 
 from resview_client.model.http_validation_error import HTTPValidationError
+from resview_client.model.location_inner import LocationInner
 from resview_client.model.reservation_batch_get_request import ReservationBatchGetRequest
 from resview_client.model.validation_error import ValidationError
